@@ -45,7 +45,7 @@ def st_system_generator_selector():
         return
 
     # get the list of system generators for the current project
-    status_code, system_generators = _backend_GET(f"/projects/{st.session_state['project_id']}/sysgen")
+    status_code, system_generators = _backend_GET(f"/projects/{st.session_state['project_id']}/sysgen/")
 
     # if successful display a selector for the system generators based on their IDs and names
     if status_code == 200:
@@ -71,10 +71,6 @@ def st_system_generator_selector():
         else:
             st.error(f"Error while loading generated designs: {system_generator}")
 
-    # display the selected system generator
-    if 'sysgen_description' in st.session_state:
-        st.metric(label=f"Selected System Generator (ID: {st.session_state['sysgen_id']})",
-                  value=st.session_state["sysgen_description"])
 
 def st_generated_design_selector():
     """A function which adds a generated design selector to the top of the page.
